# Guides

How-to guides for specific tasks and patterns. Each guide ends with a runnable example.

## Popular guides

- [Container Dependencies (Map-Reduce)](container_dependencies.md)
- [Parallelization Patterns](parallelization_patterns.md)
- [GPU Hello Torch](hello_torch.md)
- [SSH Security](ssh_security.md)
- [Custom Task Decorators](custom-task-decorators.md)
